require 'spec_helper'

describe Aigu::Rails do
  let(:base_class) { Aigu::Rails }

  describe :configure do
    let(:api_key) { '1ee7' }

    specify do
      base_class.configure do |config|
        config.api_key = api_key
      end

      expect(base_class.configuration.api_key).to eq(api_key)
    end
  end

  describe :reload_locales! do
    let(:locale_reloader) { instance_double('Aigu::Rails::Accent::LocaleReloader') }
    let(:locale) { 'fr' }

    before do
      expect(Aigu::Rails::Accent::LocaleReloader).to receive(:new).with(locale: locale).and_return(locale_reloader)
    end

    context 'without raised errors' do
      before { expect(locale_reloader).to receive(:reload!) }
      specify { base_class.reload_locales!(locale: locale) }
    end

    context 'with raised error' do
      before { expect(locale_reloader).to receive(:reload!) { raise StandardError } }
      it { expect { base_class.reload_locales!(locale: locale) }.to raise_error(Aigu::Rails::Error) }
    end
  end
end
